conf change: sensors: read and write path rename

Rename the readpath and writepath for camelcase styling to make all
configuration variables consistent.

Change-Id: I33f475075c8f40cd2029a5c0bfda950846cd5d44
Signed-off-by: Patrick Venture <venture@google.com>
diff --git a/sensors/buildjson.cpp b/sensors/buildjson.cpp
index 4bf5ea7..d62edfd 100644
--- a/sensors/buildjson.cpp
+++ b/sensors/buildjson.cpp
@@ -26,17 +26,17 @@
 void from_json(const json& j, SensorConfig& s)
 {
     j.at("type").get_to(s.type);
-    j.at("readpath").get_to(s.readpath);
+    j.at("readPath").get_to(s.readPath);
 
-    /* The writepath field is optional in a configuration */
-    auto writepath = j.find("writepath");
-    if (writepath == j.end())
+    /* The writePath field is optional in a configuration */
+    auto writePath = j.find("writePath");
+    if (writePath == j.end())
     {
-        s.writepath = "";
+        s.writePath = "";
     }
     else
     {
-        j.at("writepath").get_to(s.writepath);
+        j.at("writePath").get_to(s.writePath);
     }
 
     /* The min field is optional in a configuration. */